********
Analysis
********

.. toctree::
   :maxdepth: 1
   :caption: Modules

   analysis/base
   analysis/lpi
   analysis/partial_dependency
   analysis/regret

.. automodule:: orion.analysis
   :members:
